;****************************************************************************
;*  Name    : GTIA_V-Gate_Rev1_1.asm 
;*  Author  : Michael St. Pierre
;*  Notice  : Copyright (c) 2017 Mytek Controls
;*          : All Rights Reserved
;*  Date    : 6/28/2017
;*  Version : 1.1 (Narrowed View Port)
;*  Notes   : Over-Scan Timing Generator (V-Gate Chip)
;*          : Based on Microchip PIC12F1571
;*          : Assembled in GPUTILS v1.5.1 
;*          : Source: <https://gputils.sourceforge.io/>
;*
;*          : Firmware for Atari V-Gate Over-Scan Delete Board
;*          : (Hardware Design Rev 1.5)
;* 
;*  This program is free software; you can redistribute it and/or modify
;*  it under the terms of the GNU General Public License as published by
;*  the Free Software Foundation, either version 2 of the License, or
;*  (at your option) any later version.*
;*
;*  This program is distributed in the hope that it will be useful,
;*  but WITHOUT ANY WARRANTY; without even the implied warranty of
;*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;*  GNU General Public License for more details.
;* 
;*  You should have received a copy of the GNU General Public License along
;*  with this program.  If not, see <http://www.gnu.org/licenses/>
;*
;****************************************************************************

    list p=12F1571	      ;Define Processor
    #include <p12f1571.inc>

; Set configuration register for:
; Code protection off
; Brown-out detect off
; MCLR disabled (I/O Pin)
; Watch Dog timer disabled
; Power on reset delay enabled
; Enable External Clock Input (3.58 Mhz GTIA OSC)
; 4x PLL enabled (14.318 Mhz)

;PIC12F1571 Config Settings
    __CONFIG _CONFIG1, _FOSC_ECM & _WDTE_OFF & _PWRTE_ON & _MCLRE_OFF & _CP_OFF & _BOREN_OFF & _CLKOUTEN_OFF
    __CONFIG _CONFIG2, _WRT_OFF & _PLLEN_ON & _LVP_OFF 

;**********************************************************************
;Variables and Equates
;**********************************************************************             
    cblock 0x20
	
dlyloop

    endc

#DEFINE CSYNC   PORTA,2    
#DEFINE VGATE   PORTA,4    
#DEFINE LED     PORTA,1
#DEFINE ENABLE  PORTA,0

;**********************************************************************
;Start
;**********************************************************************

    org     0x000	      ; Processor reset vector
    goto    SetUp	      ; Set up Port I/O, IRQ, ect.

;----------------------------------------------------------------------
	
    org     0x004	      ; Processor interrupt vector

    bsf     VGATE	      ; Turn on video (start of color burst)
    movlw   01H
    call    dly_1us
    btfsc   ENABLE	      ; Leave video ON if Enable pin grounded
    bcf     VGATE	      ; Turn off video (end of color burst)

    movlw   03H
    call    dly_1us
    
    bsf     VGATE	      ; Turn on video (start of active video data)
    movlw   34H
    call    dly_1us
    nop
    nop	      ; Each 'nop' = 279 nSec
    btfsc   ENABLE	      ; Leave video ON if Enable pin grounded
    bcf     VGATE	      ; Turn off video (end of active video data)

    banksel INTCON	      ; Clear interrupt flag
    bcf     INTCON,INTF
    retfie	      ; Leave interrupt


;**********************************************************************
;Setup
;**********************************************************************

SetUp	
	
; configure Ports

    banksel TRISA
    movlw   B'11101101'	      ; RA1 & RA4 Outputs, all others input
    movwf   TRISA
    banksel WPUA		
    movwf   WPUA	      ; Enable individual pull-ups for PORTA inputs
    banksel ANSELA
    clrf    ANSELA	      ; Switch PORTA from analog to digital inputs
	
; configure interrupts
	
    banksel OPTION_REG
    bsf     OPTION_REG,INTEDG   ; 1 = interrupt on CSYNC rising edge
    bcf     OPTION_REG,7	      ; Global enable weak pull-ups

    banksel INTCON
    bsf     INTCON,INTE	      ; 1 = enables the GPIO port change interrupt
    bsf     INTCON,GIE	      ; 1 = enables all unmasked interrupts	
    goto    Main


;**********************************************************************
;Subroutines
;**********************************************************************

dly_1us
    movwf   dlyloop
dly decfsz  dlyloop,1
    goto    dly
    retlw   0


;**********************************************************************
;Main
;**********************************************************************

Main
    btfsc   ENABLE
    bsf     LED	      ; Turn on LED if V-Gate enabled
    btfss   ENABLE
    bcf     LED	      ; Turn off LED if V-Gate disabled
    goto    Main

    end





